@@ -10,7 +10,10 @@ to generate an ErrorInfo instance in other applications.
 import os
 import json
 import re
-import urlparse
+try:
+    import urlparse
+except ImportError:
+    import urllib.parse as urlparse # pylint: disable=import-error
 
 import validators
 import cherrypy
@@ -41,6 +44,31 @@ def errors_from_list(workflows):
     return indict
 
 
+def assistance_manual():
+    """
+    Returns the workflows in 'assistance-manual'
+
+    :returns: list of workflows
+    :rtype: list
+    """
+    config_dict = serverconfig.config_dict()
+
+    if 'oracle' in config_dict:
+        try:
+            oracle_db_conn = cx_Oracle.connect(*config_dict['oracle'])
+            oracle_cursor = oracle_db_conn.cursor()
+            oracle_cursor.execute(
+                "SELECT NAME FROM CMS_UNIFIED_ADMIN.workflow WHERE lower(STATUS) = 'assistance-manual'") # pylint:disable=line-too-long
+            wkfs = [row for row, in oracle_cursor]
+            oracle_db_conn.close()
+            return wkfs
+
+        except cx_Oracle.DatabaseError:
+            pass
+
+    return []
+
+
 def open_location(data_location):
     """
     This function assumes that the contents of the location is in JSON format.
@@ -53,14 +81,17 @@ def open_location(data_location):
     config_dict = serverconfig.config_dict()
 
     if 'oracle' in config_dict:
-        oracle_db_conn = cx_Oracle.connect(*config_dict['oracle']) # pylint:disable=c-extension-no-member
-        oracle_cursor = oracle_db_conn.cursor()
-        oracle_cursor.execute(
-            "SELECT NAME FROM CMS_UNIFIED_ADMIN.workflow WHERE lower(STATUS) LIKE '%manual%'")
-        wkfs = [row for row, in oracle_cursor]
-        oracle_db_conn.close()
-        cherrypy.log('Number of workflows from database: %i' % len(wkfs))
-        return errors_from_list(wkfs)
+        try:
+            oracle_db_conn = cx_Oracle.connect(*config_dict['oracle'])
+            oracle_cursor = oracle_db_conn.cursor()
+            oracle_cursor.execute(
+                "SELECT NAME FROM CMS_UNIFIED_ADMIN.workflow WHERE lower(STATUS) LIKE '%manual%'")
+            wkfs = [row for row, in oracle_cursor]
+            oracle_db_conn.close()
+            return errors_from_list(wkfs)
+
+        except cx_Oracle.DatabaseError:
+            return None
 
     raw = None
 
@@ -83,12 +114,11 @@ def open_location(data_location):
     if raw is None:
         return raw
 
-    keys = raw.keys()
-    if not (keys and isinstance(raw[keys[0]], list)):
+    if not (raw and isinstance(raw[list(raw)[0]], list)):
         return raw
 
     return errors_from_list([
-        workflow for workflow, statuses in raw.iteritems()
+        workflow for workflow, statuses in raw.items()
         if True in ['manual' in status for status in statuses]
     ])
 
@@ -113,7 +143,7 @@ def get_list_info(status_list):
     return indict
 
 
-def add_to_database(curs, data_location): # pylint: disable=too-complex
+def add_to_database(curs, data_location):
     """Add data from a file to a central database through the passed cursor
 
     :param sqlite3.Cursor curs: is the cursor to the database
